def right_tile(index_keys):
    return [['right'], index_keys]


def left_tile(index_keys):
    return [['left'], index_keys]


def top_tile(index_keys):
    return [['top'], index_keys]


def bottom_tile(index_keys):
    return [['bottom'], index_keys]


def left_top_tile(index_keys):
    return [['left', 'top'], index_keys]


def left_bottom_tile(index_keys):
    return [['left', 'bottom'], index_keys]


def right_top_tile(index_keys):
    return [['right', 'top'], index_keys]


def right_bottom_tile(index_keys):
    return [['right', 'bottom'], index_keys]


def bottom_left_tile(index_keys):
    return [['bottom', 'left'], index_keys]


def bottom_right_tile(index_keys):
    return [['bottom', 'right'], index_keys]


def top_left_tile(index_keys):
    return [['top', 'left'], index_keys]


def top_right_tile(index_keys):
    return [['top', 'right'], index_keys]
